div.post {
  width: 90%;
  margin-bottom: 2em;
}

div.post h1 {
  font-size: 1.7em;
  position: relative;
  border-bottom: none;
  font-weight: normal;
}

div.entry h3, h3.title {
  font-size: 1.0em;
}
div.post div.postmetadata {
  background:transparent url(postdatabg.jpg) no-repeat scroll left bottom;
  font-size: 0.98em;
  padding-bottom: 12px;
  padding-left: 10px;
  padding-top: 10px;
  margin-bottom:1.5em;
}

div.post div.entry {
  margin-left: 10px;
  margin-top: 25px;
  padding-top: 5px;
}

div.post div.entry p {
  margin-bottom:1.5em;
}

div.post small {
  font-size: 80%;
  color:#949494;
  display: block;
  margin-left: 2em;
  margin: 0em 0em 1em 1em;
}

ul.invisible li {
  background: none;
}

ul.simple li {
  background: transparent url(bullet_orange.png) no-repeat scroll 0 6px;
}

span.previousmonth {
 float:left;
}

span.nextmonth {
 float:right;
}

span.author {
 float:right;
 font-size: 1.2em;
}

div.creation_date {
 font-size:1.2em;
 border-bottom-style: ridge;
 border-bottom-color: #CCC;
 border-bottom-width: thin;
}
